==> haskell-hourglass-0.2.10-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.10
id: hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
key: hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Time.Types Time.System Time.Compat Data.Hourglass
    Data.Hourglass.Types Data.Hourglass.Epoch Data.Hourglass.Compat
    System.Hourglass
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
abi: e68310bbc8d7e910b2b8218d4fb59c07
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hourglass-0.2.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/hourglass-0.2.10
data-dir: /usr/share/arm-linux-ghc-8.0.1/hourglass-0.2.10
hs-libraries: HShourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
depends:
    base-4.9.0.0 deepseq-1.4.2.0
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hourglass-0.2.10-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.10
id: hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
key: hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Time.Types Time.System Time.Compat Data.Hourglass
    Data.Hourglass.Types Data.Hourglass.Epoch Data.Hourglass.Compat
    System.Hourglass
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
abi: 93372616b24bcda2d8e6dd44eab74c3a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hourglass-0.2.10
library-dirs: /usr/lib/ghc-8.0.2/site-local/hourglass-0.2.10
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/hourglass-0.2.10
hs-libraries: HShourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
depends:
    base-4.9.1.0 deepseq-1.4.2.0
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
